package logic

import (
	"context"
	"errors"
	"fusenapi/model"
	"fusenapi/utils/image"

	"fusenapi/product/internal/svc"
	"fusenapi/product/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type GetProductListLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewGetProductListLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetProductListLogic {
	return &GetProductListLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

// 获取产品列表
func (l *GetProductListLogic) GetProductList(req *types.GetProductListReq, uid int64) (resp *types.Response, err error) {
	//获取合适尺寸
	if req.Size > 0 {
		req.Size = image.GetCurrentSize(req.Size)
	}
	//获取是否存在千人千面
	userModel := model.NewFsUserModel(l.svcCtx.MysqlConn)
	userInfo, err := userModel.FindOne(l.ctx, uid)
	if err != nil {
		return nil, err
	}
	if userInfo.Id == 0 {
		return nil, errors.New("user not exists")
	}
	return
}
